/*******************************************************************************
*
*	TITLE:		encoder.h 
*
*	VERSION:	0.3 (Beta)                           
*
*	DATE:		01-Jan-2005
*
*	AUTHOR:		R. Kevin Watson
*
*	COMMENTS:	You are free to use this source code for any non-commercial
*				use. Please do not make copies of this source code, modified
*				or un-modified, publicly available on the internet or
*				elsewhere without permission. Thanks.
*
*				Copyright 2004-2005 R. Kevin Watson. All rights are reserved.
*
********************************************************************************
*
*	CHANGE LOG:
*
*	DATE         REV  DESCRIPTION
*	-----------  ---  ----------------------------------------------------------
*	20-Dec-2003  0.1  RKW - Original code.
*	18-Feb-2004  0.2  RKW - Reassigned the encoder digital inputs to run
*	                  on the FRC robot controller too.
*	01-Jan-2005  0.3  RKW - Get_Left_Encoder_Count(), Get_Right_Encoder_Count(),
*	                  Set_Left_Encoder_Count() and Set_Right_Encoder_Count()
*	                  functions added.
*	01-Jan-2005  0.3  RKW - Renamed Int_1_Handler() and Int_2_Handler() to
*	                  Left_Encoder_Int_Handler() and Right_Encoder_Int_Handler
*	                  respectively.
*	01-Jan-2005  0.3  RKW - Altered the interrupt service routines to easily
*	                  flip the direction the encoders count by altering the
*	                  RIGHT_ENCODER_TICK_DELTA and LEFT_ENCODER_TICK_DELTA
*	                  #defines found in encoder.h
*
*******************************************************************************/

#ifndef _encoder_h
#define _encoder_h

// Digital input pin assigned to the left wheel
// encoder's phase-B output. Make sure this pin
// is configured as an input in user_routines.c/
// User_Initialization().
#define LEFT_ENCODER_PHASE_B_PIN	rc_dig_in06

// Digital input pin assigned to the right wheel
// encoder's phase-B output. Make sure this pin
// is configured as an input in user_routines.c/
// User_Initialization().
#define RIGHT_ENCODER_PHASE_B_PIN	rc_dig_in08

// change the sign of these if you need	to flip
// the way the encoders count. For instance, if
// a given encoder count increases in the positive 
// direction when rotating counter-clockwise, but 
// you want it to count in the negative direction 
// when rotating in the counter-clockwise direction,
// flip the sign and it'll work the way you need it
// to. By default, the left encoder is -1 because
// left/right mounted encoders will count in the
// opposite direction when the 'bot is moving in
// a straight line.
#define LEFT_ENCODER_TICK_DELTA 	(1)
#define RIGHT_ENCODER_TICK_DELTA 	(-1)

// function prototypes
void Initialize_Encoders(void);			// call this to initialize the encoder
										// software

long Get_Left_Encoder_Count(void);		// call this to get the current left 
										// wheel's encoder count

long Get_Right_Encoder_Count(void);		// call this to get the current right
										// wheel's encoder count

void Set_Left_Encoder_Count(long);		// call this to set the left wheel's 
										// encoder count

void Set_Right_Encoder_Count(long);		// call this to set the right wheel's
										// encoder count

void Left_Encoder_Int_Handler(void);	// left wheel encoder interrupt handler

void Right_Encoder_Int_Handler(void);	// right wheel encoder interrupt handler

#endif
